==> upx-ucl-beta_1.94+0.20051214cvs.orig.tar.gz: upx-ucl-beta-1.94+0.20051214cvs.orig/src/stub/l_t_n2b.h <==
/* l_t_n2b.h -- created from l_t_n2b.bin, 668 (0x29c) bytes

   This file is part of the UPX executable compressor.

   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
   Copyright (C) 1996-2005 Laszlo Molnar
   All Rights Reserved.

   UPX and the UCL library are free software; you can redistribute them
   and/or modify them under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.
   If not, write to the Free Software Foundation, Inc.,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

   Markus F.X.J. Oberhumer              Laszlo Molnar
   <mfx@users.sourceforge.net>          <ml1050@users.sourceforge.net>
 */


#define NRV2B_LOADER_ADLER32 0xb05aee80
#define NRV2B_LOADER_CRC32   0x148f8dcd

unsigned char nrv2b_loader[668] = {
 32,  8,103,  6, 46,104,  0,  4, 96,  4, 32, 47,  0,  4, 72,231,   /* 0x   0 */
127,254, 36, 64, 80,138, 44, 90, 40, 14, 36,188,117,112, 49, 49,   /* 0x  10 */
221,218, 36,206, 36,188,117,112, 49, 50,221,218, 40, 82, 36,206,   /* 0x  20 */
 36,188,117,112, 49, 51, 38, 68,215,252,117,112, 50, 49, 32, 60,   /* 0x  30 */
117,112, 50, 50, 73,236,255, 96, 76,236, 39,238,  0,120, 72,227,   /* 0x  40 */
119,228, 76,236, 39,238,  0, 80, 72,227,119,228, 76,236, 39,238,   /* 0x  50 */
  0, 40, 72,227,119,228, 76,212, 39,238, 72,227,119,228,117, 49,   /* 0x  60 */
102,210,117, 50, 39, 36, 81,200,255,252, 69,250,  0,188, 47,  4,   /* 0x  70 */
122, 73, 63, 34, 83,133,100,250, 63,124, 78,113,  0,130, 97, 32,   /* 0x  80 */
 40, 68,112,128,126,255,124,152,235, 78, 36, 68,213,252,117,112,   /* 0x  90 */
 51, 49, 78,210, 44,195, 44,195, 44,195, 44,195,117, 52,102,244,   /* 0x  a0 */
 72,120,255,255, 66,167, 47, 60,  1, 84,  0, 22, 78, 65, 79,239,   /* 0x  b0 */
  0, 12, 74,128,103, 96, 72,122,  0, 16, 63, 60,  0, 38, 78, 78,   /* 0x  c0 */
 92,143, 96, 82, 46, 73, 78,208, 47, 56,  0, 16, 47, 56,  0, 44,   /* 0x  d0 */
 47, 56,  0,244, 34, 79, 65,250,255,236, 33,200,  0, 16, 33,200,   /* 0x  e0 */
  0, 44, 33,200,  0,244, 78,113, 65,250,  0,  6,244,248, 96, 22,   /* 0x  f0 */
 65,250,  0, 20, 78,122,  0,  2, 34,  0,  0, 65,  8,  8, 78,123,   /* 0x 100 */
 16,  2, 78,123,  0,  2, 33,223,  0,244, 33,223,  0, 44, 33,223,   /* 0x 110 */
  0, 16, 78,113, 78,117, 78,117, 79,239,  0,152, 76,223,127,254,   /* 0x 120 */
 32,  8,103,  2,159,207, 78,249, 10,  0, 36, 73,110,102,111, 58,   /* 0x 130 */
 32, 84,104,105,115, 32,102,105,108,101, 32,105,115, 32,112, 97,   /* 0x 140 */
 99,107,101,100, 32,119,105,116,104, 32,116,104,101, 32, 85, 80,   /* 0x 150 */
 88, 32,101,120,101, 99,117,116, 97, 98,108,101, 32,112, 97, 99,   /* 0x 160 */
107,101,114, 32,104,116,116,112, 58, 47, 47,117,112,120, 46,115,   /* 0x 170 */
102, 46,110,101,116, 32, 36, 10,  0, 36, 73,100, 58, 32, 85, 80,   /* 0x 180 */
 88, 32, 85, 80, 88, 86, 32, 67,111,112,121,114,105,103,104,116,   /* 0x 190 */
 32, 40, 67, 41, 32, 49, 57, 57, 54, 45, 50, 48, 48, 53, 32,116,   /* 0x 1a0 */
104,101, 32, 85, 80, 88, 32, 84,101, 97,109, 46, 32, 65,108,108,   /* 0x 1b0 */
 32, 82,105,103,104,116,115, 32, 82,101,115,101,114,118,101,100,   /* 0x 1c0 */
 46, 32, 36, 10,  0,  0,  0,  0, 85, 80, 88, 33,161,216,208,213,   /* 0x 1d0 */
  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   /* 0x 1e0 */
  0,  0,  0,  0,  0,  0,  0, 45, 24,219,208,  0,100,  8,102,248,   /* 0x 1f0 */
 16, 27,209,  0,101,242,114,  1,118,  0,208,  0,102,  4, 16, 27,   /* 0x 200 */
209,  0,211,129,208,  0,100,242,102,  6, 16, 27,209,  0,100,234,   /* 0x 210 */
 87,129,101, 10,225,137, 18, 27, 70,129,103, 72, 42,  1,208,  0,   /* 0x 220 */
102,  4, 16, 27,209,  0,215, 67,208,  0,102,  4, 16, 27,209,  0,   /* 0x 230 */
215, 67, 74, 67,102, 26, 82, 67,208,  0,102,  4, 16, 27,209,  0,   /* 0x 240 */
215, 67,208,  0,100,242,102,  6, 16, 27,209,  0,100,234, 84, 67,   /* 0x 250 */
 69,244, 88,  0, 34,  5,146,134,215, 71, 24,218, 24,218, 81,203,   /* 0x 260 */
255,252, 96,134, 44, 60,117,112, 52, 49,117, 51, 32, 78, 34, 68,   /* 0x 270 */
211,216,211,195,217,145, 22, 24,103, 10,182,  5,102,244, 67,233,   /* 0x 280 */
  0,254, 96,242, 78,215,  1,248,  0,158,  0,  2                    /* 0x 290 */
};

==> upx-ucl-beta_1.95+0.20060318cvs.orig.tar.gz: upx-ucl-beta-1.95+0.20060318cvs.orig/src/stub/l_t_n2b.h <==
/* l_t_n2b.h -- created from l_t_n2b.bin, 668 (0x29c) bytes

   This file is part of the UPX executable compressor.

   Copyright (C) 1996-2006 Markus Franz Xaver Johannes Oberhumer
   Copyright (C) 1996-2006 Laszlo Molnar
   Copyright (C) 2000-2006 John F. Reiser
   All Rights Reserved.

   UPX and the UCL library are free software; you can redistribute them
   and/or modify them under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.
   If not, write to the Free Software Foundation, Inc.,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

   Markus F.X.J. Oberhumer              Laszlo Molnar
   <mfx@users.sourceforge.net>          <ml1050@users.sourceforge.net>
 */


#define NRV2B_LOADER_SIZE    668
#define NRV2B_LOADER_ADLER32 0x36bbef0f
#define NRV2B_LOADER_CRC32   0x4f682ad4

unsigned char nrv2b_loader[668] = {
 32,  8,103,  6, 46,104,  0,  4, 96,  4, 32, 47,  0,  4, 72,231,   /* 0x   0 */
127,254, 36, 64, 80,138, 44, 90, 40, 14, 36,188,117,112, 49, 49,   /* 0x  10 */
221,218, 36,206, 36,188,117,112, 49, 50,221,218, 40, 82, 36,206,   /* 0x  20 */
 36,188,117,112, 49, 51, 38, 68,215,252,117,112, 50, 49, 32, 60,   /* 0x  30 */
117,112, 50, 50, 73,236,255, 96, 76,236, 39,238,  0,120, 72,227,   /* 0x  40 */
119,228, 76,236, 39,238,  0, 80, 72,227,119,228, 76,236, 39,238,   /* 0x  50 */
  0, 40, 72,227,119,228, 76,212, 39,238, 72,227,119,228,117, 49,   /* 0x  60 */
102,210,117, 50, 39, 36, 81,200,255,252, 69,250,  0,188, 47,  4,   /* 0x  70 */
122, 73, 63, 34, 83,133,100,250, 63,124, 78,113,  0,130, 97, 32,   /* 0x  80 */
 40, 68,112,128,126,255,124,152,235, 78, 36, 68,213,252,117,112,   /* 0x  90 */
 51, 49, 78,210, 44,195, 44,195, 44,195, 44,195,117, 52,102,244,   /* 0x  a0 */
 72,120,255,255, 66,167, 47, 60,  1, 84,  0, 22, 78, 65, 79,239,   /* 0x  b0 */
  0, 12, 74,128,103, 96, 72,122,  0, 16, 63, 60,  0, 38, 78, 78,   /* 0x  c0 */
 92,143, 96, 82, 46, 73, 78,208, 47, 56,  0, 16, 47, 56,  0, 44,   /* 0x  d0 */
 47, 56,  0,244, 34, 79, 65,250,255,236, 33,200,  0, 16, 33,200,   /* 0x  e0 */
  0, 44, 33,200,  0,244, 78,113, 65,250,  0,  6,244,248, 96, 22,   /* 0x  f0 */
 65,250,  0, 20, 78,122,  0,  2, 34,  0,  0, 65,  8,  8, 78,123,   /* 0x 100 */
 16,  2, 78,123,  0,  2, 33,223,  0,244, 33,223,  0, 44, 33,223,   /* 0x 110 */
  0, 16, 78,113, 78,117, 78,117, 79,239,  0,152, 76,223,127,254,   /* 0x 120 */
 32,  8,103,  2,159,207, 78,249, 10,  0, 36, 73,110,102,111, 58,   /* 0x 130 */
 32, 84,104,105,115, 32,102,105,108,101, 32,105,115, 32,112, 97,   /* 0x 140 */
 99,107,101,100, 32,119,105,116,104, 32,116,104,101, 32, 85, 80,   /* 0x 150 */
 88, 32,101,120,101, 99,117,116, 97, 98,108,101, 32,112, 97, 99,   /* 0x 160 */
107,101,114, 32,104,116,116,112, 58, 47, 47,117,112,120, 46,115,   /* 0x 170 */
102, 46,110,101,116, 32, 36, 10,  0, 36, 73,100, 58, 32, 85, 80,   /* 0x 180 */
 88, 32, 85, 80, 88, 86, 32, 67,111,112,121,114,105,103,104,116,   /* 0x 190 */
 32, 40, 67, 41, 32, 49, 57, 57, 54, 45, 85, 80, 88, 89, 32,116,   /* 0x 1a0 */
104,101, 32, 85, 80, 88, 32, 84,101, 97,109, 46, 32, 65,108,108,   /* 0x 1b0 */
 32, 82,105,103,104,116,115, 32, 82,101,115,101,114,118,101,100,   /* 0x 1c0 */
 46, 32, 36, 10,  0,  0,  0,  0, 85, 80, 88, 33,161,216,208,213,   /* 0x 1d0 */
  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   /* 0x 1e0 */
  0,  0,  0,  0,  0,  0,  0, 45, 24,219,208,  0,100,  8,102,248,   /* 0x 1f0 */
 16, 27,209,  0,101,242,114,  1,118,  0,208,  0,102,  4, 16, 27,   /* 0x 200 */
209,  0,211,129,208,  0,100,242,102,  6, 16, 27,209,  0,100,234,   /* 0x 210 */
 87,129,101, 10,225,137, 18, 27, 70,129,103, 72, 42,  1,208,  0,   /* 0x 220 */
102,  4, 16, 27,209,  0,215, 67,208,  0,102,  4, 16, 27,209,  0,   /* 0x 230 */
215, 67, 74, 67,102, 26, 82, 67,208,  0,102,  4, 16, 27,209,  0,   /* 0x 240 */
215, 67,208,  0,100,242,102,  6, 16, 27,209,  0,100,234, 84, 67,   /* 0x 250 */
 69,244, 88,  0, 34,  5,146,134,215, 71, 24,218, 24,218, 81,203,   /* 0x 260 */
255,252, 96,134, 44, 60,117,112, 52, 49,117, 51, 32, 78, 34, 68,   /* 0x 270 */
211,216,211,195,217,145, 22, 24,103, 10,182,  5,102,244, 67,233,   /* 0x 280 */
  0,254, 96,242, 78,215,  1,248,  0,158,  0,  2                    /* 0x 290 */
};
